mindroot.coreplugins.admin package
==================================

Submodules
----------

mindroot.coreplugins.admin.agent\_importer module
-------------------------------------------------

.. automodule:: mindroot.coreplugins.admin.agent_importer
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.admin.agent\_router module
-----------------------------------------------

.. automodule:: mindroot.coreplugins.admin.agent_router
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.admin.asset\_manager module
------------------------------------------------

.. automodule:: mindroot.coreplugins.admin.asset_manager
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.admin.command\_router module
-------------------------------------------------

.. automodule:: mindroot.coreplugins.admin.command_router
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.admin.mcp\_catalog\_routes module
------------------------------------------------------

.. automodule:: mindroot.coreplugins.admin.mcp_catalog_routes
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.admin.mcp\_publish\_routes module
------------------------------------------------------

.. automodule:: mindroot.coreplugins.admin.mcp_publish_routes
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.admin.mcp\_registry\_routes module
-------------------------------------------------------

.. automodule:: mindroot.coreplugins.admin.mcp_registry_routes
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.admin.mcp\_routes module
---------------------------------------------

.. automodule:: mindroot.coreplugins.admin.mcp_routes
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.admin.mod module
-------------------------------------

.. automodule:: mindroot.coreplugins.admin.mod
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.admin.oauth\_callback\_router module
---------------------------------------------------------

.. automodule:: mindroot.coreplugins.admin.oauth_callback_router
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.admin.persona\_handler module
--------------------------------------------------

.. automodule:: mindroot.coreplugins.admin.persona_handler
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.admin.persona\_router module
-------------------------------------------------

.. automodule:: mindroot.coreplugins.admin.persona_router
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.admin.plugin\_manager module
-------------------------------------------------

.. automodule:: mindroot.coreplugins.admin.plugin_manager
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.admin.plugin\_router module
------------------------------------------------

.. automodule:: mindroot.coreplugins.admin.plugin_router
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.admin.plugin\_router\_fixed module
-------------------------------------------------------

.. automodule:: mindroot.coreplugins.admin.plugin_router_fixed
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.admin.plugin\_router\_new\_not\_working module
-------------------------------------------------------------------

.. automodule:: mindroot.coreplugins.admin.plugin_router_new_not_working
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.admin.plugin\_routes module
------------------------------------------------

.. automodule:: mindroot.coreplugins.admin.plugin_routes
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.admin.registry\_settings\_routes module
------------------------------------------------------------

.. automodule:: mindroot.coreplugins.admin.registry_settings_routes
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.admin.router module
----------------------------------------

.. automodule:: mindroot.coreplugins.admin.router
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.admin.server\_router module
------------------------------------------------

.. automodule:: mindroot.coreplugins.admin.server_router
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.admin.service\_models module
-------------------------------------------------

.. automodule:: mindroot.coreplugins.admin.service_models
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.admin.settings\_router module
--------------------------------------------------

.. automodule:: mindroot.coreplugins.admin.settings_router
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: mindroot.coreplugins.admin
   :members:
   :show-inheritance:
   :undoc-members:
